| Title: | Geographically Weighted Partial Correlation Mapper |
|---|---|
| Description: | An interactive mapping tool for geographically weighted correlation and partial correlation. Geographically weighted partial correlation coefficients are calculated following (Percival and Tsutsumida, 2017)<doi:10.1553/giscience2017_01_s36> and are described in greater detail in (Tsutsumida et al., 2019)<doi:10.5194/ica-abs-1-372-2019> and (Percival et al., 2021)<arXiv:2101.03491>. |
| Authors: | Joseph Emile Honour Percival [aut, cre] (ORCID: <https://orcid.org/0000-0001-5941-4601>), Narumasa Tsutsumida [aut] (ORCID: <https://orcid.org/0000-0002-6333-0301>) |
| Maintainer: | Joseph Emile Honour Percival <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.3 |
| Built: | 2026-06-05 09:16:50 UTC |
| Source: | https://github.com/gwpcor/gwpcormapper |
Launches gwpcorMapper.
run_app(...)run_app(...)
... |
A series of options to be used inside the app. |
null
## Not run: gwpcormapper::run_app() ## End(Not run)## Not run: gwpcormapper::run_app() ## End(Not run)
The original source of the data is the Portal Site of Official Statistics of Japan website (https://www.e-stat.go.jp/) Note that the original dataset was modified to provide English translations.
tokyo2005tokyo2005
An object of class sf (inherits from data.frame) with 3134 rows and 229 columns.
An sf object with census statistics of the 23 special wards of Tokyo from the year 2005.
Joseph Percival and Narumasa Tsutsumida [email protected]
## Not run: data(tokyo2005) summary(tokyo2005) ## End(Not run)## Not run: data(tokyo2005) summary(tokyo2005) ## End(Not run)